#ifndef HOMESCREENMODEL_H
#define HOMESCREENMODEL_H

#include <QAbstractListModel>
#include <QPair>
#include <QString>

class HomescreenModel : public QAbstractListModel
{
    Q_OBJECT

public:
    enum Roles {
        NameRole = Qt::UserRole + 1,
        IconSourceRole
    };

public:
    explicit HomescreenModel(QObject *parent = 0);
    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role) const;
    Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
    
private:
    QList< QPair<QString, QString> > m_list;
};

#endif // HOMESCREENMODEL_H
